@@ -25,6 +25,7 @@
 #include "oxygengtkutils.h"
 #include "oxygenpalette.h"
 
+#include <iostream>
 #include <gtk/gtk.h>
 
 namespace Oxygen
@@ -35,17 +36,18 @@ namespace Oxygen
     {
         Blend = 1<<0,
         Sunken = 1<<1,
-        Flat = 1<<2,
-        Focus = 1<<3,
-        Hover = 1<<4,
-        NoFill = 1<<5,
-        Vertical = 1<<6,
-        Alpha = 1<<7,
-        Round = 1<<8,
-        Contrast = 1<<9,
-        Selected = 1<<10,
-        Disabled = 1<<11,
-        Menu = 1<<12
+        Active = 1<<2,
+        Flat = 1<<3,
+        Focus = 1<<4,
+        Hover = 1<<5,
+        NoFill = 1<<6,
+        Vertical = 1<<7,
+        Alpha = 1<<8,
+        Round = 1<<9,
+        Contrast = 1<<10,
+        Selected = 1<<11,
+        Disabled = 1<<12,
+        Menu = 1<<13
     };
 
     class StyleOptions: public Flags<StyleOption>
@@ -62,12 +64,18 @@ namespace Oxygen
             Flags<StyleOption>( f )
         {}
 
+        //! constructor
+        StyleOptions( Flags<StyleOption> f):
+            Flags<StyleOption>( f )
+        {}
+
         //! constructor from widget
         StyleOptions( GtkWidget* widget, GtkStateType state, GtkShadowType shadow = GTK_SHADOW_NONE )
         {
             if( state == GTK_STATE_INSENSITIVE ) (*this) |= Disabled;
             else if( state == GTK_STATE_PRELIGHT ) (*this) |= Hover;
             else if( state == GTK_STATE_SELECTED ) (*this) |= Selected;
+            else if( state == GTK_STATE_ACTIVE ) (*this) |= Active;
 
             if( shadow == GTK_SHADOW_IN ) (*this) |= Sunken;
             if( widget && gtk_widget_has_focus(widget) ) (*this)|=Focus;
@@ -82,8 +90,13 @@ namespace Oxygen
         /*! it is used to pass custom colors to painting routines */
         Palette::ColorSet _customColors;
 
+        //! streamer
+        friend std::ostream& operator << (std::ostream& out, const StyleOptions& options );
+
     };
 
 }
 
+OX_DECLARE_OPERATORS_FOR_FLAGS( Oxygen::StyleOptions )
+
 #endif
