@@ -76,8 +76,11 @@ namespace Oxygen
     {
 
         if( _hooksInitialized ) return;
-        _styleSetHook.connect( "style-set", (GSignalEmissionHook)styleSetHook, this );
-        _buttonReleaseHook.connect( "button-release-event", (GSignalEmissionHook)buttonReleaseHook, this );
+        if(_mode!=Disabled)
+        {
+            _styleSetHook.connect( "style-set", (GSignalEmissionHook)styleSetHook, this );
+            _buttonReleaseHook.connect( "button-release-event", (GSignalEmissionHook)buttonReleaseHook, this );
+        }
         _hooksInitialized = true;
 
     }
@@ -667,6 +670,7 @@ namespace Oxygen
         _blackList.push_back( "MetaFrames" );
         _blackList.push_back( "SPHRuler" );
         _blackList.push_back( "SPVRuler" );
+        _blackList.push_back( "GtkPlug" );
     }
 
     //________________________________________________________________________________
